@@ -23,7 +23,7 @@ use Mouse::Util::TypeConstraints;
 use MouseX::Types::Path::Class 0.06;
 use namespace::autoclean 0.11;
 
-our $VERSION = '0.981';
+our $VERSION = '0.982';
 
 BEGIN {
     # Need to create types before loading other Sqitch classes.
@@ -212,13 +212,13 @@ has user_name => (
                 Win32API::Net::UserGetInfo( "", $sysname, 10, my $info = {} );
                 return $sysname unless $info->{fullName};
                 require Encode::Locale;
-                Encode::decode( locale => $info->{fullName} );
+                return Encode::decode( locale => $info->{fullName} );
             }
             require User::pwent;
             my $name = (User::pwent::getpwnam($sysname)->gecos)[0]
                 || return $sysname;
             require Encode::Locale;
-            Encode::decode( locale => $name );
+            return Encode::decode( locale => $name );
         };
     }
 );
